﻿#############################################################
# Title       : Export AD student data                      #
# Author      : Eric Krebill                                #
# Date / Ver  : 10/29/2018 / 1.2                            #
#############################################################

######################### Universal Variables #########################
[xml]$univar = Get-Content $env:HOMEDRIVE\PowerShell\UniVar\UniVar.xml
$exportfile = $univar.var.stufile + 'EXPORT_for_Koha.csv'
$emaildomain = $univar.var.domain
$studentou = $univar.var.stuou
######### Consult README before modifying Universal Variables #########

Import-Module -Name ActiveDirectory

Remove-Item -Path $exportFile -Force # Remove the old Export File
$out = @() # Define "out" as an empty array
$outputdelimiter = ',' # Output file delimiter

# Grab all users in the Student OU who have an email address
$students = Get-ADUser -filter "mail -like '*$emaildomain'" -Searchbase $studentou -ResultSetSize $null -Properties SamAccountName,surname,givenName,mail,company,description,enabled `

# Set the headers for the Export File
$headers = 'cardnumber,surname,firstname,email,branchcode,categorycode,sort1,sort2'
Set-Content $exportfile $headers -ErrorAction Stop 

FOREACH ($student in $students)
{
  IF ($($student.enabled) -eq $true)
  {
    ##### CardNumber
    $out += $student.sAMAccountName
    ##### Surname
    $out += $student.surname
    ##### FirstName
    $out += $student.givenName
    ##### EmailAddress
    $out += $student.mail
    ##### BranchCode - STATIC
    $out += 'DIST'
    ##### CategoryCode - STATIC
    $out += 'Student'
    ##### Sort1
    $out += $student.company
    ##### Sort2
    $out += $student.description
    
    # Set the delimiter and export data in the array to the Export File
    $out = $out -join $outputdelimiter
    Add-Content $exportfile $out -ErrorAction Stop
    $out = @()
  }
}
