﻿#############################################################
# Title       : GAM - Add students to print groups          #
# Author      : Eric Krebill                                #
# Date /Ver   : 11/14/2018 / 2.2                            #
#############################################################

######################### Universal Variables #########################
[xml]$univar = Get-Content C:\PowerShell\UniVar\UniVar.xml
$logFile = $univar.var.stulog + "LOG_GAM_PrintGroups.txt"
$detailFile = $univar.var.stulog + "DETAIL_GAM_PrintGroups.txt"
$gamPath = $univar.var.gam
$studentou = $univar.var.stuou
$emaildomain = $univar.var.domain
######### Consult README before modifying Universal Variables #########

# Start Current School Year Calculation Function
# Sets the necessary variables for the function
[int]$currentmonth = Get-Date -UFormat %m
[int]$currentyear = Get-Date -UFormat %Y
$yearchange = IF ($currentmonth -le 7) { 0 } ELSE { 1 }
$currentschoolyear = ($currentYear + $yearchange)

# Change the properties variables to match the fields you need to use in the script.  
# Do not remove whenCreated variable as that's needed later on.
$students = Get-ADUser -filter "mail -like '*$emaildomain'" -Searchbase $studentou -ResultSetSize $null -Properties whenCreated,mail,Description `

# Logging and housekeeping
Add-Content -Path $logFile -Value "Process started $(Get-Date)" -PassThru

FOREACH ($user in $students)
{
  $email = $user.mail
  $gradyear = $user.Description

  #Checks to see if the user was created within the last day
  IF ($user.whenCreated -ge ((Get-Date).AddDays(-1)).Date)
  {
  
    IF (($currentschoolyear + '3') -ge $gradyear)
    {
      $printgroup = 'prt_hs_stu@domain.com'
    }
    ELSEIF ((($currentschoolyear + '4') -le $gradyear) -and (($currentschoolyear + '6') -ge $gradyear))
    {
      $printgroup = 'prt_ms_stu@domain.com'
    }
    ELSEIF ((($currentschoolyear + '7') -le $gradyear) -and (($currentschoolyear + '9') -ge $gradyear))
    {
      $printgroup = 'prt_sl_stu@domain.com'
    }
    Else 
    {
      $printgroup = 'prt_mac_stu@domain.com'
    }
  
    & $gamPath update group $printgroup add member $email

    Add-Content -Path $detailFile -Value "$(Get-Date) - $email added to $printgroup" -PassThru
  }
}

# More logging
Add-Content -Path $logFile -Value "Process completed $(Get-Date)" -PassThru
